CLIS_DESC = [
    ("temporal", ".temporal.temporal_cli.cli"),
]
STEP_DECORATORS_DESC = [
    ("temporal_internal", ".temporal.temporal_decorator.TemporalInternalDecorator"),
]
DEPLOYER_IMPL_PROVIDERS_DESC = [
    ("temporal", ".temporal.temporal_deployer.TemporalDeployer"),
]
